==> qtjambi-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiWidgets/QGraphicsSceneMoveEvent_shell.cpp <==
#include "QGraphicsSceneMoveEvent_shell.h"
#include <QtJambi/Cast>

#if QT_CONFIG(graphicsview)


void deleter_QGraphicsSceneMoveEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QGraphicsSceneMoveEvent")
    QGraphicsSceneMoveEvent *_ptr = reinterpret_cast<QGraphicsSceneMoveEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QGraphicsSceneMoveEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QGraphicsSceneMoveEvent_shell) ); }

jmethodID QGraphicsSceneMoveEvent_shell::__shell_javaMethod(int pos) const { return QGraphicsSceneMoveEvent_shell::__shell()->javaMethod(typeid(QGraphicsSceneMoveEvent), pos); }

// emitting (writeShellConstructor)
QGraphicsSceneMoveEvent_shell::QGraphicsSceneMoveEvent_shell()
    : QGraphicsSceneMoveEvent()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QGraphicsSceneMoveEvent::QGraphicsSceneMoveEvent_shell()", QGraphicsSceneMoveEvent_shell::__shell())
    QGraphicsSceneMoveEvent_shell::__shell()->constructed(typeid(QGraphicsSceneMoveEvent));
}

// emitting (writeShellDestructor)
QGraphicsSceneMoveEvent_shell::~QGraphicsSceneMoveEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QGraphicsSceneMoveEvent::~QGraphicsSceneMoveEvent()", QGraphicsSceneMoveEvent_shell::__shell())
    QGraphicsSceneMoveEvent_shell::__shell()->destructed(typeid(QGraphicsSceneMoveEvent));
}

void QGraphicsSceneMoveEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QGraphicsSceneMoveEvent_shell*>(ptr)->QGraphicsSceneMoveEvent_shell::__shell()->tryDeleteShell(typeid(QGraphicsSceneMoveEvent));
}

// emitting Virtual overrides (virtualFunctions)
QEvent* QGraphicsSceneMoveEvent_shell::clone() const
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QGraphicsSceneMoveEvent::", QGraphicsSceneMoveEvent_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QEvent*  __qt_return_value = nullptr;
            QTJAMBI_TRY {
                if(jobject __java_this = QGraphicsSceneMoveEvent_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QEvent* >(__jni_env, __java_return_value);
                    QtJambiAPI::setCppOwnership(__jni_env, __java_return_value);
                } else {
                    QGraphicsSceneMoveEvent_shell::__shell()->warnForMethod("QGraphicsSceneMoveEvent::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QGraphicsSceneMoveEvent::");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QEvent::clone();
        }
    }else{
        return QEvent::clone();
    }
}

void QGraphicsSceneMoveEvent_shell::setAccepted(bool accepted0)
{
    if(jmethodID method_id = __shell_javaMethod(1)){
        QTJAMBI_JAVA_METHOD_CALL("QGraphicsSceneMoveEvent::", QGraphicsSceneMoveEvent_shell::__shell())
        if(JniEnvironment __jni_env{300}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if(jobject __java_this = QGraphicsSceneMoveEvent_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    __jni_env->CallVoidMethod(__java_this, method_id, accepted0);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                } else {
                    QGraphicsSceneMoveEvent_shell::__shell()->warnForMethod("QGraphicsSceneMoveEvent::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QGraphicsSceneMoveEvent::");
            } QTJAMBI_TRY_END
        }else{
            QEvent::setAccepted(static_cast<bool>(accepted0));
        }
    }else{
        QEvent::setAccepted(static_cast<bool>(accepted0));
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)

#endif // QT_CONFIG(graphicsview)

// emitting (writeConstructors)
// new QGraphicsSceneMoveEvent()
void __qt_construct_QGraphicsSceneMoveEvent_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QGraphicsSceneMoveEvent()")
#if QT_CONFIG(graphicsview)
    Q_UNUSED(__java_arguments)
    QGraphicsSceneMoveEvent *__qt_this = new(__qtjambi_ptr) QGraphicsSceneMoveEvent_shell();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
#else
    Q_UNUSED(__jni_object)
    Q_UNUSED(__java_arguments)
    Q_UNUSED(__qtjambi_ptr)
    JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(graphicsview)
}

// destruct QGraphicsSceneMoveEvent_shell
void __qt_destruct_QGraphicsSceneMoveEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QGraphicsSceneMoveEvent")

#if QT_CONFIG(graphicsview)

    reinterpret_cast<QGraphicsSceneMoveEvent_shell*>(ptr)->~QGraphicsSceneMoveEvent_shell();

#else
    Q_UNUSED(ptr)

#endif // QT_CONFIG(graphicsview)

}

// emitting  (functionsInTargetLang writeFinalFunction)
// QGraphicsSceneMoveEvent::QGraphicsSceneMoveEvent()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QGraphicsSceneMoveEvent_initialize_1native__Lio_qt_widgets_QGraphicsSceneMoveEvent_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QGraphicsSceneMoveEvent::QGraphicsSceneMoveEvent()")
    QTJAMBI_TRY {
#if QT_CONFIG(graphicsview)
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QGraphicsSceneMoveEvent_0, sizeof(QGraphicsSceneMoveEvent_shell), typeid(QGraphicsSceneMoveEvent), true, &deleter_QGraphicsSceneMoveEvent, nullptr);
#else
        Q_UNUSED(__jni_object)
        Q_UNUSED(__jni_class)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(graphicsview)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QGraphicsSceneMoveEvent::newPos()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QGraphicsSceneMoveEvent_newPos_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(graphicsview)
        const QGraphicsSceneMoveEvent *__qt_this = QtJambiAPI::objectFromNativeId<QGraphicsSceneMoveEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QGraphicsSceneMoveEvent::newPos()const", __qt_this)
        QPointF __qt_return_value = __qt_this->newPos();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(graphicsview)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QGraphicsSceneMoveEvent::oldPos()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QGraphicsSceneMoveEvent_oldPos_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(graphicsview)
        const QGraphicsSceneMoveEvent *__qt_this = QtJambiAPI::objectFromNativeId<QGraphicsSceneMoveEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QGraphicsSceneMoveEvent::oldPos()const", __qt_this)
        QPointF __qt_return_value = __qt_this->oldPos();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(graphicsview)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QGraphicsSceneMoveEvent::setNewPos(QPointF)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QGraphicsSceneMoveEvent_setNewPos_1native_1cref_1QPointF__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID pos0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
#if QT_CONFIG(graphicsview)
        QGraphicsSceneMoveEvent *__qt_this = QtJambiAPI::objectFromNativeId<QGraphicsSceneMoveEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QGraphicsSceneMoveEvent::setNewPos(QPointF)", __qt_this)
        const QPointF& __qt_pos0 = QtJambiAPI::valueReferenceFromNativeId<QPointF>(pos0);
        __qt_this->setNewPos(__qt_pos0);
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        Q_UNUSED(pos0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(graphicsview)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QGraphicsSceneMoveEvent::setOldPos(QPointF)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QGraphicsSceneMoveEvent_setOldPos_1native_1cref_1QPointF__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID pos0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
#if QT_CONFIG(graphicsview)
        QGraphicsSceneMoveEvent *__qt_this = QtJambiAPI::objectFromNativeId<QGraphicsSceneMoveEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QGraphicsSceneMoveEvent::setOldPos(QPointF)", __qt_this)
        const QPointF& __qt_pos0 = QtJambiAPI::valueReferenceFromNativeId<QPointF>(pos0);
        __qt_this->setOldPos(__qt_pos0);
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        Q_UNUSED(pos0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(graphicsview)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QGraphicsSceneMoveEvent(){
    using namespace RegistryAPI;

#if QT_CONFIG(graphicsview)

    const std::type_info& typeId = registerObjectTypeInfo<QGraphicsSceneMoveEvent>("QGraphicsSceneMoveEvent", "io/qt/widgets/QGraphicsSceneMoveEvent");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "clone", "()Lio/qt/core/QEvent;"),
        FunctionInfo(/* 1 */ "setAccepted", "(Z)V")});
    registerConstructorInfos(typeId, &__qt_destruct_QGraphicsSceneMoveEvent, {
        ConstructorInfo(&__qt_construct_QGraphicsSceneMoveEvent_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QGraphicsSceneMoveEvent);
    registerSizeOfShell(typeId, sizeof(QGraphicsSceneMoveEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QGraphicsSceneEvent, QGraphicsSceneMoveEvent>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags

#endif //QT_CONFIG(graphicsview)

}

==> qtjambi-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiWidgets/QGraphicsSceneMoveEvent_shell.cpp <==
#include "QGraphicsSceneMoveEvent_shell.h"
#include <QtJambi/Cast>

#if QT_CONFIG(graphicsview)


void deleter_QGraphicsSceneMoveEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QGraphicsSceneMoveEvent")
    QGraphicsSceneMoveEvent *_ptr = reinterpret_cast<QGraphicsSceneMoveEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QGraphicsSceneMoveEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QGraphicsSceneMoveEvent_shell) ); }

jmethodID QGraphicsSceneMoveEvent_shell::__shell_javaMethod(int pos) const { return QGraphicsSceneMoveEvent_shell::__shell()->javaMethod(typeid(QGraphicsSceneMoveEvent), pos); }

// emitting (writeShellConstructor)
QGraphicsSceneMoveEvent_shell::QGraphicsSceneMoveEvent_shell()
    : QGraphicsSceneMoveEvent()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QGraphicsSceneMoveEvent::QGraphicsSceneMoveEvent_shell()", QGraphicsSceneMoveEvent_shell::__shell())
    QGraphicsSceneMoveEvent_shell::__shell()->constructed(typeid(QGraphicsSceneMoveEvent));
}

// emitting (writeShellDestructor)
QGraphicsSceneMoveEvent_shell::~QGraphicsSceneMoveEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QGraphicsSceneMoveEvent::~QGraphicsSceneMoveEvent()", QGraphicsSceneMoveEvent_shell::__shell())
    QGraphicsSceneMoveEvent_shell::__shell()->destructed(typeid(QGraphicsSceneMoveEvent));
}

void QGraphicsSceneMoveEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QGraphicsSceneMoveEvent_shell*>(ptr)->QGraphicsSceneMoveEvent_shell::__shell()->tryDeleteShell(typeid(QGraphicsSceneMoveEvent));
}

// emitting Virtual overrides (virtualFunctions)
QEvent* QGraphicsSceneMoveEvent_shell::clone() const
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QGraphicsSceneMoveEvent::", QGraphicsSceneMoveEvent_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QEvent*  __qt_return_value = nullptr;
            QTJAMBI_TRY {
                if(jobject __java_this = QGraphicsSceneMoveEvent_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QEvent* >(__jni_env, __java_return_value);
                    QtJambiAPI::setCppOwnership(__jni_env, __java_return_value);
                } else {
                    QGraphicsSceneMoveEvent_shell::__shell()->warnForMethod("QGraphicsSceneMoveEvent::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QGraphicsSceneMoveEvent::");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QEvent::clone();
        }
    }else{
        return QEvent::clone();
    }
}

void QGraphicsSceneMoveEvent_shell::setAccepted(bool accepted0)
{
    if(jmethodID method_id = __shell_javaMethod(1)){
        QTJAMBI_JAVA_METHOD_CALL("QGraphicsSceneMoveEvent::", QGraphicsSceneMoveEvent_shell::__shell())
        if(JniEnvironment __jni_env{300}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if(jobject __java_this = QGraphicsSceneMoveEvent_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    __jni_env->CallVoidMethod(__java_this, method_id, accepted0);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                } else {
                    QGraphicsSceneMoveEvent_shell::__shell()->warnForMethod("QGraphicsSceneMoveEvent::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QGraphicsSceneMoveEvent::");
            } QTJAMBI_TRY_END
        }else{
            QEvent::setAccepted(static_cast<bool>(accepted0));
        }
    }else{
        QEvent::setAccepted(static_cast<bool>(accepted0));
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)

#endif // QT_CONFIG(graphicsview)

// emitting (writeConstructors)
// new QGraphicsSceneMoveEvent()
void __qt_construct_QGraphicsSceneMoveEvent(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QGraphicsSceneMoveEvent()")
#if QT_CONFIG(graphicsview)
    Q_UNUSED(__java_arguments)
    QGraphicsSceneMoveEvent *__qt_this = new(__qtjambi_ptr) QGraphicsSceneMoveEvent_shell();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
#else
    Q_UNUSED(__jni_object)
    Q_UNUSED(__java_arguments)
    Q_UNUSED(__qtjambi_ptr)
    Q_UNUSED(__qtjambi_is_generic)
    JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(graphicsview)
}

// QGraphicsSceneMoveEvent::QGraphicsSceneMoveEvent()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QGraphicsSceneMoveEvent_initialize_1native__Lio_qt_widgets_QGraphicsSceneMoveEvent_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QGraphicsSceneMoveEvent::QGraphicsSceneMoveEvent()")
    QTJAMBI_TRY {
#if QT_CONFIG(graphicsview)
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QGraphicsSceneMoveEvent, sizeof(QGraphicsSceneMoveEvent_shell), typeid(QGraphicsSceneMoveEvent), true, &deleter_QGraphicsSceneMoveEvent, nullptr);
#else
        Q_UNUSED(__jni_object)
        Q_UNUSED(__jni_class)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(graphicsview)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QGraphicsSceneMoveEvent_shell
void __qt_destruct_QGraphicsSceneMoveEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QGraphicsSceneMoveEvent")

#if QT_CONFIG(graphicsview)

    reinterpret_cast<QGraphicsSceneMoveEvent_shell*>(ptr)->~QGraphicsSceneMoveEvent_shell();

#else
    Q_UNUSED(ptr)

#endif // QT_CONFIG(graphicsview)

}

// emitting  (functionsInTargetLang writeFinalFunction)
// QGraphicsSceneMoveEvent::newPos()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QGraphicsSceneMoveEvent_newPos_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(graphicsview)
        const QGraphicsSceneMoveEvent *__qt_this = QtJambiAPI::objectFromNativeId<QGraphicsSceneMoveEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QGraphicsSceneMoveEvent::newPos()const", __qt_this)
        QPointF __qt_return_value = __qt_this->newPos();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(graphicsview)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QGraphicsSceneMoveEvent::oldPos()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QGraphicsSceneMoveEvent_oldPos_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(graphicsview)
        const QGraphicsSceneMoveEvent *__qt_this = QtJambiAPI::objectFromNativeId<QGraphicsSceneMoveEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QGraphicsSceneMoveEvent::oldPos()const", __qt_this)
        QPointF __qt_return_value = __qt_this->oldPos();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(graphicsview)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QGraphicsSceneMoveEvent::setNewPos(QPointF)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QGraphicsSceneMoveEvent_setNewPos_1native_1cref_1QPointF__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID pos0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
#if QT_CONFIG(graphicsview)
        QGraphicsSceneMoveEvent *__qt_this = QtJambiAPI::objectFromNativeId<QGraphicsSceneMoveEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QGraphicsSceneMoveEvent::setNewPos(QPointF)", __qt_this)
        const QPointF& __qt_pos0 = QtJambiAPI::valueReferenceFromNativeId<QPointF>(pos0);
        __qt_this->setNewPos(__qt_pos0);
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        Q_UNUSED(pos0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(graphicsview)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QGraphicsSceneMoveEvent::setOldPos(QPointF)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QGraphicsSceneMoveEvent_setOldPos_1native_1cref_1QPointF__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID pos0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
#if QT_CONFIG(graphicsview)
        QGraphicsSceneMoveEvent *__qt_this = QtJambiAPI::objectFromNativeId<QGraphicsSceneMoveEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QGraphicsSceneMoveEvent::setOldPos(QPointF)", __qt_this)
        const QPointF& __qt_pos0 = QtJambiAPI::valueReferenceFromNativeId<QPointF>(pos0);
        __qt_this->setOldPos(__qt_pos0);
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        Q_UNUSED(pos0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(graphicsview)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QGraphicsSceneMoveEvent(){
    using namespace RegistryAPI;

#if QT_CONFIG(graphicsview)

    const std::type_info& typeId = registerObjectTypeInfo<QGraphicsSceneMoveEvent>("QGraphicsSceneMoveEvent", "io/qt/widgets/QGraphicsSceneMoveEvent");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "clone", "()Lio/qt/core/QEvent;"),
        FunctionInfo(/* 1 */ "setAccepted", "(Z)V")});
    registerConstructorInfos(typeId, &__qt_destruct_QGraphicsSceneMoveEvent, {
        ConstructorInfo(&__qt_construct_QGraphicsSceneMoveEvent, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QGraphicsSceneMoveEvent);
    registerSizeOfShell(typeId, sizeof(QGraphicsSceneMoveEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QGraphicsSceneEvent, QGraphicsSceneMoveEvent>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags

#endif //QT_CONFIG(graphicsview)

}
